import ContainerWrapper from '../ContainerWrapper';
import actionName from '../../utils/actionName';

import dropdownCollapse from './redux/dropdownCollapse';
import dropdownChange from './redux/dropdownChange';
import dropdownExpand from './redux/dropdownExpand';
import dropdownHighlightedIndexChange from './redux/dropdownHighlightedIndexChange';


export const changeType = actionName('CHANGE');
export const collapseType = actionName('COLLAPSE');
export const expandType = actionName('EXPAND');
export const highlightedIndexChangeType = actionName('HIGHLIGHTED-INDEX-CHANGE');

export default ({
    Component
} = {}) => {

    const mapDispatchToProps = (dispatch, props) => {
        const { customActionMetadata: custom, path, root } = props;
        const actionTypePrefix = props.actionTypePrefix || 'DROPDOWN';

        return {
            onChange: (value) => dispatch(dropdownChange({ custom, path, root, type: changeType(actionTypePrefix), value })),
            onCollapse: () => dispatch(dropdownCollapse({ path, root, type: collapseType(actionTypePrefix) })),
            onExpand: () => dispatch(dropdownExpand({ path, root, type: expandType(actionTypePrefix) })),
            onHighlightedIndexChange: (highlightedIndex) => dispatch(dropdownHighlightedIndexChange({ highlightedIndex, path, root, type: highlightedIndexChangeType(actionTypePrefix) }))
        };
    };

    return ContainerWrapper({
        Component,
        mapDispatchToProps
    });

};
