import React, { PropTypes } from 'react';

import FoundationButton from '../button/FoundationButton';

import FoundationControlLayout from '../layout/FoundationControlLayout';
import FoundationControlsLayout from '../layout/FoundationControlsLayout';

import FoundationLightboxActions from './FoundationLightboxActions';
import FoundationLightboxContent from './FoundationLightboxContent';
import FoundationLightboxDescription from './FoundationLightboxDescription';
import FoundationLightboxHeader from './FoundationLightboxHeader';
import FoundationLightboxSpinner from './FoundationLightboxSpinner';

import FoundationFormFieldErrors from '../error/FoundationFormFieldErrors';

import { pgettext } from '../../utils/lang';


const FoundationLightboxBasicContent = React.createClass({

    propTypes: {
        action: PropTypes.shape({
            onClick: PropTypes.func.isRequired,
            text: PropTypes.string.isRequired,
            ui: PropTypes.string.isRequired
        }),
        children: PropTypes.node,
        description: PropTypes.node,
        errors: PropTypes.object,
        fetch: PropTypes.shape({
            description: PropTypes.node,
            title: PropTypes.node
        }),
        fetching: PropTypes.bool,
        onClose: PropTypes.func,
        submit: PropTypes.shape({
            description: PropTypes.node,
            title: PropTypes.node
        }),
        submitting: PropTypes.bool,
        title: PropTypes.node
    },

    getDefaultProps() {
        return {
            action: {
                onClick: () => {},
                text: pgettext('generic-action', 'Ok'),
                ui: 'primary'
            },
            description: '',
            errors: {},
            fetch: null,
            fetching: false,
            onClose: () => {},
            submit: null,
            submitting: false,
            title: ''
        };
    },

    renderAction() {
        const { action, submitting } = this.props;
        if (action === null) {
            return null;
        }

        const { onClick, text, ui } = action;
        return (
            <FoundationControlLayout>
                <FoundationButton
                    loading={ submitting }
                    onClick={ onClick }
                    ui={ [ui, 'mobile-stretched'] }>
                    { text }
                </FoundationButton>
            </FoundationControlLayout>
        );
    },

    renderClose() {
        const { action, onClose, submitting } = this.props;
        return (
            <FoundationControlLayout>
                <FoundationButton
                    disabled={ submitting }
                    onClick={ onClose }
                    ui={ ['mobile-stretched'] }>
                    { pgettext('generic-action', action !== null ? 'Cancel' : 'Close') }
                </FoundationButton>
            </FoundationControlLayout>
        );
    },

    renderSpinnerDescription(spinner) {
        if (spinner === null || spinner.description === null) {
            return null;
        }

        return (
            <FoundationLightboxDescription>
                { spinner.description }
            </FoundationLightboxDescription>
        );
    },

    renderSpinnerTitle(spinner) {
        if (spinner === null || spinner.title === null) {
            return null;
        }

        return (
            <FoundationLightboxHeader>
                { spinner.title }
            </FoundationLightboxHeader>
        );
    },

    renderSpinner(spinner) {
        return (
            <FoundationLightboxContent>
                { this.renderSpinnerTitle(spinner) }
                { this.renderSpinnerDescription(spinner) }
                <FoundationLightboxSpinner />
            </FoundationLightboxContent>
        );
    },

    render() {
        const { children, description, errors, fetch, fetching, submit, submitting, title } = this.props;

        if (fetching) {
            return this.renderSpinner(fetch);
        }

        if (submitting && submit !== null) {
            return this.renderSpinner(submit);
        }

        return (
            <FoundationLightboxContent>
                <FoundationLightboxHeader>
                    { title }
                </FoundationLightboxHeader>
                <FoundationLightboxDescription>
                    { description }
                </FoundationLightboxDescription>
                { children }
                <FoundationFormFieldErrors
                    errors={ errors } />
                <FoundationLightboxActions>
                    <FoundationControlsLayout
                        column="mobile">
                        { this.renderAction() }
                        { this.renderClose() }
                    </FoundationControlsLayout>
                </FoundationLightboxActions>
            </FoundationLightboxContent>
        );
    }

});

export default FoundationLightboxBasicContent;
